#include <stdint.h>
#include "hardware.h"
#include "utilities.h"

static uint16_t g_timestamp = 0;
static uint16_t g_crystalCount = 0;
static bool g_waitForTimestamp = false;

// wird alle 14 Ticks des 32768 Hz Uhrenquarzes aufgerufen,
// also mit ca. 2340,57 Hz
void onInterrupt()
{
  // Takte des Uhrenquarzes zhlen
  g_crystalCount += 14;
  
  // grne LED mit 1 Hz blinken lassen
  setGreenLed(g_crystalCount > 16384);
  
  // Timestamp nach einer Sekunde erhhen
  if (g_crystalCount > 32768) {
      g_crystalCount -= 32768;
      if (g_waitForTimestamp) {
        g_waitForTimestamp = false;
        wakeup();
      }
      g_timestamp++;
  }
}

int main(void)
{
  // Hardware initialisieren
  initHardware();

  // Endlosschleife
  while (true) {
    // ADC-Wert holen
    uint16_t adc = getAdc();
    
    // in Volt umrechnen, wie es am Eingang des ADCs anliegt
    float volt = 1.5f / 1024.0f * float(adc);
    
    // Korrektur fr Spannungsteiler und andere Ungenauigkeiten
    volt *= 9.1324f;
    
    // bis zum nchsten Timestamp warten
    g_waitForTimestamp = true;
    lpm0Halt();
    
    // Timestamp und ungerechnete Spannung ausgeben
    printInt(&sendByte, g_timestamp);
    sendByte(' ');
    printFloat(&sendByte, volt);
    
    // Zeilenvorschub bertragen
    sendByte(13);
    sendByte(10);
  }
}
